==> dde-dock_4.7.3.2.orig.tar.xz: translations/dde-dock_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>ContainerItem</name>
    <message>
        <location filename="../frame/item/containeritem.cpp" line="33"/>
        <source>Click to display hidden icon</source>
        <translation>Clique para exibir o ícone oculto</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="55"/>
        <source>Datetime</source>
        <translation>Data e hora</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="119"/>
        <source>12 Hour Time</source>
        <translation>Formato 12 horas</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="121"/>
        <source>24 Hour Time</source>
        <translation>Formato 24 horas</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="127"/>
        <source>Time Settings</source>
        <translation>Alterar data e hora</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="51"/>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="53"/>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="59"/>
        <source>Network settings</source>
        <translation>Configurações de rede</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="106"/>
        <source>Unknown device</source>
        <translation>Dispositivo desconhecido</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="112"/>
        <source>Unknown volume</source>
        <translation>Volume desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="40"/>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="90"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="96"/>
        <source>Unmount all</source>
        <translation>Desmontar todos</translation>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="46"/>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="47"/>
        <source>Efficient Mode</source>
        <translation>Eficiente</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="48"/>
        <source>Top</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="49"/>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="50"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="51"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="52"/>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="53"/>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="54"/>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="55"/>
        <source>Keep Shown</source>
        <translation>Continuar exibindo </translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="56"/>
        <source>Keep Hidden</source>
        <translation>Continuar oculto</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="57"/>
        <source>Smart Hide</source>
        <translation>Ocultação inteligente</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="94"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="102"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="109"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="116"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="120"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="38"/>
        <source>Launcher</source>
        <translation>Lançador</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <location filename="../plugins/network/networkplugin.cpp" line="46"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
</context>
<context>
    <name>PopupControlWidget</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="88"/>
        <source>Empty</source>
        <translation>Esvaziar</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="93"/>
        <source>This action cannot be restored</source>
        <translation>Esta ação não pode ser restaurada</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="95"/>
        <source>Are you sure to empty 1 item ?</source>
        <translation>Deseja remover 1 item da lixeira?</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="97"/>
        <source>Are you sure to empty %1 items ?</source>
        <translation>Deseja remover %1 itens da lixeira?</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="78"/>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="148"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="86"/>
        <source>Remaining Capacity %1</source>
        <translation>Bateria restante %1 </translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="92"/>
        <source>Charged %1</source>
        <translation>Carregado %1</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="94"/>
        <source>Charging %1</source>
        <translation>Carregando %1</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="154"/>
        <source>Restart</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="166"/>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="172"/>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="160"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="58"/>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="180"/>
        <source>Switch account</source>
        <translation>Trocar de conta</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="190"/>
        <source>Power settings</source>
        <translation>Configurações de energia</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="56"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="75"/>
        <source>Application</source>
        <translation>Aplicação</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="79"/>
        <source>Unmute</source>
        <translation>Ativar o som</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="81"/>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="87"/>
        <source>Audio Settings</source>
        <translation>Configurações de áudio</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="215"/>
        <source>Current Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <location filename="../plugins/sound/soundplugin.cpp" line="41"/>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
</context>
<context>
    <name>SystemTrayPlugin</name>
    <message>
        <location filename="../plugins/system-tray/systemtrayplugin.cpp" line="46"/>
        <source>System Tray</source>
        <translation>Bandeja do sistema</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="61"/>
        <source>Trash - %1 file</source>
        <translation>Lixeira - %1 arquivo</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="63"/>
        <source>Trash - %1 files</source>
        <translation>Lixeira - %1 arquivos</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="65"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="73"/>
        <source>Empty</source>
        <translation>Esvaziar</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="68"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="73"/>
        <source>No Network</source>
        <translation>Sem rede</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="83"/>
        <source>Wired connection: %1</source>
        <translation>Conexão com fio %1</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="75"/>
        <source>No Network</source>
        <translation>Sem rede</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="85"/>
        <source>Wireless Connection: %1</source>
        <translation>Conexão wireless: %1 </translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="55"/>
        <source>Auto-connect</source>
        <translation>Auto-conectar</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="67"/>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="68"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="174"/>
        <source>Wireless Network</source>
        <translation>Rede wireless</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="176"/>
        <source>Wireless Network %1</source>
        <translation>Rede wireless %1</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="432"/>
        <source>Password required to connect to &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;</source>
        <translation>Digite a senha para conectar a &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;</translation>
    </message>
</context>
</TS>

==> dde-dock_4.9.1.1.orig.tar.xz: translations/dde-dock_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>ContainerItem</name>
    <message>
        <location filename="../frame/item/containeritem.cpp" line="33"/>
        <source>Click to display hidden icon</source>
        <translation>Clique para exibir o ícone oculto</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <location filename="../plugins/keyboard-layout/dbusadaptors.cpp" line="138"/>
        <source>Add keyboard layout</source>
        <translation>Adicionar layout de teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="57"/>
        <source>Datetime</source>
        <translation>Data e hora</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="146"/>
        <source>12 Hour Time</source>
        <translation>Formato 12 horas</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="148"/>
        <source>24 Hour Time</source>
        <translation>Formato 24 horas</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="154"/>
        <source>Time Settings</source>
        <translation>Alterar data e hora</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="59"/>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="61"/>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="67"/>
        <source>Network settings</source>
        <translation>Configurações de rede</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="88"/>
        <source>Are you sure to empty %1 items?</source>
        <translation>Quer mesmo limpar %1 itens?</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="93"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="93"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="113"/>
        <source>This action cannot be restored</source>
        <translation>Esta ação não pode ser desfeita</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="106"/>
        <source>Unknown device</source>
        <translation>Dispositivo desconhecido</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="112"/>
        <source>Unknown volume</source>
        <translation>Volume desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="40"/>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="90"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="96"/>
        <source>Unmount all</source>
        <translation>Desmontar todos</translation>
    </message>
</context>
<context>
    <name>DockPluginsController</name>
    <message>
        <location filename="../frame/controller/dockpluginscontroller.cpp" line="157"/>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>O plugin %1 não é compatível com o sistema.</translation>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="47"/>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="48"/>
        <source>Efficient Mode</source>
        <translation>Eficiente</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="49"/>
        <source>Top</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="50"/>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="51"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="52"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="53"/>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="54"/>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="55"/>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="56"/>
        <source>Keep Shown</source>
        <translation>Continuar exibindo </translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="57"/>
        <source>Keep Hidden</source>
        <translation>Continuar oculto</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="58"/>
        <source>Smart Hide</source>
        <translation>Ocultação inteligente</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="94"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="102"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="109"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="116"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="120"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="105"/>
        <source>Launcher</source>
        <translation>Lançador</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <location filename="../plugins/network/networkplugin.cpp" line="49"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <location filename="../plugins/onboard/onboardplugin.cpp" line="35"/>
        <location filename="../plugins/onboard/onboardplugin.cpp" line="46"/>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <location filename="../plugins/onboard/onboardplugin.cpp" line="106"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="46"/>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="71"/>
        <source>Remaining Capacity %1</source>
        <translation>Bateria restante %1 </translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="76"/>
        <source>Charged %1</source>
        <translation>Carregado %1</translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="78"/>
        <source>Charging %1</source>
        <translation>Carregando %1</translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="132"/>
        <source>Power settings</source>
        <translation>Configurações de energia</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="117"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="123"/>
        <source>Restart</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="136"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="143"/>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="149"/>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="129"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="157"/>
        <source>Switch account</source>
        <translation>Trocar de conta</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="164"/>
        <source>Power settings</source>
        <translation>Configurações de energia</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="46"/>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="62"/>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="54"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="72"/>
        <source>Application</source>
        <translation>Aplicação</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="78"/>
        <source>Unmute</source>
        <translation>Ativar o som</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="80"/>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="86"/>
        <source>Audio Settings</source>
        <translation>Configurações de áudio</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="207"/>
        <source>Current Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <location filename="../plugins/sound/soundplugin.cpp" line="40"/>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="52"/>
        <source>Trash</source>
        <translation>Lixeira</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="90"/>
        <source>Trash - %1 file</source>
        <translation>Lixeira - %1 arquivo</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="92"/>
        <source>Trash - %1 files</source>
        <translation>Lixeira - %1 arquivos</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="71"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="79"/>
        <source>Empty</source>
        <translation>Esvaziar</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <location filename="../plugins/tray/trayplugin.cpp" line="59"/>
        <source>System Tray</source>
        <translation>Bandeja do sistema</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="47"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="199"/>
        <source>Wired connection: %1</source>
        <translation>Conexão com fio %1</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="49"/>
        <source>No Network</source>
        <translation>Sem rede</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="275"/>
        <source>Wireless Connection: %1</source>
        <translation>Conexão wireless: %1 </translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelesslist.cpp" line="158"/>
        <source>Wireless Network</source>
        <translation>Rede wireless</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelesslist.cpp" line="160"/>
        <source>Wireless Network %1</source>
        <translation>Rede wireless %1</translation>
    </message>
</context>
</TS>
